@@ -124,9 +124,7 @@ def backup_conversation(console, messages, master_plan):
 
 def write_user_config():
     """Writes the current configuration to the user's config file."""
-    user_config_dir = os.path.join(AGENTMAKE_USER_DIR, "biblemate")
-    Path(user_config_dir).mkdir(parents=True, exist_ok=True)
-    config_file = os.path.join(user_config_dir, "config.py")
+    config_file = os.path.join(os.path.dirname(os.path.realpath(__file__)), "config.py")
     configurations = f"""agent_mode={config.agent_mode}
 prompt_engineering={config.prompt_engineering}
 max_steps={config.max_steps}
@@ -364,10 +362,13 @@ async def main_async():
 
             # Prompt Engineering
             if not specified_tool == "@@" and config.prompt_engineering:
-                async def run_prompt_engineering():
-                    nonlocal user_request
-                    user_request = agentmake(messages if messages else user_request, follow_up_prompt=user_request if messages else None, tool="improve_prompt", **AGENTMAKE_CONFIG)[-1].get("content", "").strip()[20:-4]
-                await thinking(run_prompt_engineering, "Prompt Engineering ...")
+                try:
+                    async def run_prompt_engineering():
+                        nonlocal user_request
+                        user_request = agentmake(messages if messages else user_request, follow_up_prompt=user_request if messages else None, tool="improve_prompt", **AGENTMAKE_CONFIG)[-1].get("content", "").strip()[20:-4]
+                    await thinking(run_prompt_engineering, "Prompt Engineering ...")
+                except:
+                    pass
 
             if not messages:
                 messages = [
